@@ -15,12 +15,14 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  */
 
+#include "config.h"
+
 #include <glade/glade.h>
 #include "zenity.h"
 #include "util.h"
@@ -54,10 +56,7 @@ zenity_entry (ZenityData *data, ZenityEntryData *entry_data)
   if (data->dialog_title)
     gtk_window_set_title (GTK_WINDOW (dialog), data->dialog_title);
 	
-  if (data->window_icon)
-    zenity_util_set_window_icon (dialog, data->window_icon);
-  else
-    zenity_util_set_window_icon (dialog, ZENITY_IMAGE_FULLPATH ("zenity-entry.png"));
+  zenity_util_set_window_icon (dialog, data->window_icon, ZENITY_IMAGE_FULLPATH ("zenity-entry.png"));
 
   if (data->width > -1 || data->height > -1)
     gtk_window_set_default_size (GTK_WINDOW (dialog), data->width, data->height);
@@ -75,12 +74,13 @@ zenity_entry (ZenityData *data, ZenityEntryData *entry_data)
   if (entry_data->entry_text)
     gtk_entry_set_text (GTK_ENTRY (entry), entry_data->entry_text);
 
-  if (!entry_data->visible)
-    g_object_set (G_OBJECT (entry), "visibility", entry_data->visible, NULL);
+  if (entry_data->hide_text)
+    g_object_set (G_OBJECT (entry), "visibility", FALSE, NULL);
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (text), entry);
 
   zenity_util_show_dialog (dialog);
+
   gtk_main ();
 }
 
@@ -98,12 +98,10 @@ zenity_entry_dialog_response (GtkWidget *widget, int response, gpointer data)
       if (text != NULL)
         g_print ("%s\n", text);
 
-      gtk_main_quit ();
       break;
 
     case GTK_RESPONSE_CANCEL:
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_CANCEL);
-      gtk_main_quit ();
       break;
 
     default:
@@ -111,4 +109,5 @@ zenity_entry_dialog_response (GtkWidget *widget, int response, gpointer data)
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
   }
+  gtk_main_quit ();
 }
